/*
ChatRoomSecurityLevel.java
Copyright (C) 2010  Belledonne Communications, Grenoble, France

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.linphone.core;


/**
* TODO move to encryption engine object when available
* LinphoneChatRoomSecurityLevel is used to indicate the encryption security level
* of a chat room. 
*
*/
public enum ChatRoomSecurityLevel {
    /**
    * Security failure. 
    *
    */
    Unsafe(0),

    /**
    * No encryption. 
    *
    */
    ClearText(1),

    /**
    * Encrypted. 
    *
    */
    Encrypted(2),

    /**
    * Encrypted and verified. 
    *
    */
    Safe(3);

    protected final int mValue;

    private ChatRoomSecurityLevel (int value) {
        mValue = value;
    }

    static public ChatRoomSecurityLevel fromInt(int value) throws RuntimeException {
        switch(value) {
        case 0: return Unsafe;
        case 1: return ClearText;
        case 2: return Encrypted;
        case 3: return Safe;
        default:
            throw new RuntimeException("Unhandled enum value " + value + " for ChatRoomSecurityLevel");
        }
    }

    public int toInt() {
        return mValue;
    }
}
